measuretools.scale_measure_and_adjust_time_signature
====================================================

.. autofunction:: abjad.tools.measuretools.scale_measure_and_adjust_time_signature.scale_measure_and_adjust_time_signature
   :noindex:
